@@ -12,8 +12,8 @@
 #define PROGRAM_NAME_UPPERCASE "Clifm"
 #define PROGRAM_NAME "clifm"
 #define PROGRAM_DESC "The command line file manager"
-#define VERSION "1.27"
-#define DATE "Jan 7, 2026"
+#define VERSION "1.27.1"
+#define DATE "Jan 9, 2026"
 #define AUTHOR "L. Abramovich"
 #define CONTACT "https://github.com/leo-arch/clifm"
 #define LICENSE "GPL2+"
@@ -500,7 +500,7 @@ extern time_t curdir_mtime;
 #define MAX_TRASH     INT_MAX
 #define MAX_BOOKMARKS INT_MAX
 
-/* File creation attempt limit (e.g. tmp dir, dup file, or trashed file) */
+/* File creation attempt limit (e.g., tmp dir, dup file, trashed file, etc) */
 #define MAX_FILE_CREATION_TRIES 1000
 
 /* Max length of a file size in human format */
@@ -897,7 +897,7 @@ extern time_t curdir_mtime;
 #define JUMP_ENTRY_PERMANENT_CHR '+'
 
 #define MAX_TIME_STR 256
-#define MAX_NAMELEN_AUTO (-2) /* Macro for MaxFilenameLen=auto */
+#define MAX_NAMELEN_AUTO (-2) /* Macro for MaxFilenameLen=N% */
 
 #define SHADE_TYPE_UNSET     0
 #define SHADE_TYPE_8COLORS   1
@@ -1962,9 +1962,9 @@ extern size_t
 	zombies;
 
 #ifndef _NO_ICONS
-extern size_t *name_icons_hashes;
-extern size_t *dir_icons_hashes;
-extern size_t *ext_icons_hashes;
+extern size_t *name_icon_hashes;
+extern size_t *dir_icon_hashes;
+extern size_t *ext_icon_hashes;
 #ifndef OLD_ICON_LOOKUP
 extern size_t *ext_table;
 #endif
