@@ -2,7 +2,7 @@
  * This file is part of Clifm
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- * SPDX-FileCopyrightText: 2016-2025 L. Abramovich <leo.clifm@outlook.com>
+ * SPDX-FileCopyrightText: 2016-2026 L. Abramovich <leo.clifm@outlook.com>
 */
 
 /* misc.c -- functions that do not fit in any other file */
@@ -1101,14 +1101,14 @@ save_last_path(char *last_path_tmp)
 		return;
 	}
 
-	for (size_t i = 0; i < MAX_WS; i++) {
+	for (int i = 0; i < MAX_WS; i++) {
 		if (!workspaces[i].path)
 			continue;
 
-		if ((size_t)cur_ws == i)
-			fprintf(last_fp, "*%zu:%s\n", i, workspaces[i].path);
+		if (cur_ws == i)
+			fprintf(last_fp, "*%d:%s\n", i, workspaces[i].path);
 		else
-			fprintf(last_fp, "%zu:%s\n", i, workspaces[i].path);
+			fprintf(last_fp, "%d:%s\n", i, workspaces[i].path);
 	}
 
 	fclose(last_fp);
@@ -1219,9 +1219,9 @@ free_stuff(void)
 #endif /* RUN_CMD */
 
 #if !defined(_NO_ICONS)
-	free(name_icons_hashes);
-	free(dir_icons_hashes);
-	free(ext_icons_hashes);
+	free(name_icon_hashes);
+	free(dir_icon_hashes);
+	free(ext_icon_hashes);
 #ifndef OLD_ICON_LOOKUP
 	free(ext_table);
 #endif
@@ -1467,9 +1467,8 @@ set_max_filename_len_auto(void)
 	if (conf.max_name_len_auto == UNSET || conf.max_name_len == UNSET)
 		return;
 
-	if ((conf.columned == 0 || files == 1) && conf.long_view == 0) {
-		/* Displaying in a single column or there is just one file in the list:
-		 * Do not truncate names. */
+	if (conf.columned == 0 && conf.long_view == 0) {
+		/* Displaying in a single column: Do not truncate names. */
 		conf.max_name_len = term_cols;
 		return;
 	}
@@ -1724,7 +1723,7 @@ handle_stdin(void)
 
 		suffix = gen_rand_str(RAND_SUFFIX_LEN);
 		char *temp = tmp_dir ? tmp_dir : P_tmpdir;
-		const size_t tmp_len = strlen(temp) + 13;
+		const size_t tmp_len = strlen(temp) + RAND_SUFFIX_LEN + 7;
 		stdin_tmp_dir = xnmalloc(tmp_len, sizeof(char));
 		snprintf(stdin_tmp_dir, tmp_len, "%s/vdir.%s", temp,
 			suffix ? suffix : "nTmp0B9&54");
